@@ -8,7 +8,7 @@ use Exporter 'import';
 
 our @EXPORT_OK = qw(floyd_warshall);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 sub floyd_warshall {
@@ -42,7 +42,7 @@ Algorithm::Graphs::TransitiveClosure::Tiny - Calculate the transitive closure.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 
 =head1 SYNOPSIS
@@ -83,13 +83,13 @@ works on hashes only,
 =item *
 
 uses C<undef> for hash values, so an incidence must be checked with
-C<exists()> (but for the input hash you are not forced tu use C<undef>),
+C<exists()> (but for the input hash you are not forced to use C<undef>),
 
 =item *
 
-assumes that the hash keys are integers 0, ..., I<N>-1 (for some integer I<N>)
-and this I<N> must be passed as second argument. This is needed to fix a
-problem in the original implementation (see nect item).
+assumes that the hash keys are integers 0, ..., I<N>-1 (for some positive
+integer I<N>) and this I<N> must be passed as second argument. This is needed
+to fix a problem in the original implementation (see next item).
 
 =item *
 
@@ -113,7 +113,7 @@ from L<Algorithm::Graphs::TransitiveClosure> results in:
 
 No change. The vertice from 1 to 2 is missing (you would need to add
 C<2=E<gt>{}> to C<$g> to get it right). But if you call C<floyd_warshall($g,
-3)> from C<Algorithm::Graphs::TransitiveClosure::Tiny> then the result is
+3)> from C<Algorithm::Graphs::TransitiveClosure::Tiny>, then the result is
 correct:
 
            {
@@ -122,7 +122,8 @@ correct:
                    2 => undef},
            }
 
-Vertice from 1 to 2 has been added!
+Vertice from 1 to 2 has been added! (Also note that you could use 1 instead of
+C<undef> as hash value, but the value added by the function is C<undef> anyway!)
 
 =back
 
